==> cyanlib-1.0.9%2B1.21.5-sources.jar: fr/aeldit/cyanlib/lib/gui/CyanLibConfigScreen.java <==
package fr.aeldit.cyanlib.lib.gui;

import fr.aeldit.cyanlib.lib.config.CyanLibOptionsStorage;
import fr.aeldit.cyanlib.lib.config.ICyanLibConfig;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_353;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_4667;
import net.minecraft.class_5244;
import net.minecraft.class_7919;
import java.util.Objects;

import static fr.aeldit.cyanlib.lib.CyanLib.CONFIG_CLASS_INSTANCES;

@Environment(EnvType.CLIENT)
public class CyanLibConfigScreen extends class_4667
{
    private final CyanLibOptionsStorage cyanLibOptionsStorage;
    private final class_437 parent;
    private final ICyanLibConfig configOptionsClass;

    //? if <=1.19.3 {
    /*private ButtonListWidget optionList;
     *///?} else {
    private class_353 optionList;
    //?}

    public CyanLibConfigScreen(class_437 previous, class_437 parent, String modId)
    {
        super(
                previous, class_310.method_1551().field_1690,
                class_2561.method_43471("%s.screen.options.title".formatted(modId))
        );
        this.field_21335 = parent;
        this.cyanLibOptionsStorage = CONFIG_CLASS_INSTANCES.get(modId).getOptionsStorage();
        this.configOptionsClass = this.cyanLibOptionsStorage.getConfigClass();
    }

    @Override
    public void method_25419()
    {
        cyanLibOptionsStorage.writeConfig();
        Objects.requireNonNull(field_22787).method_1507(field_21335);
    }

    //? if <=1.19.2 {
    /*public void render(MatrixStack matrices, int mouseX, int mouseY, float tickDelta)
    {
        this.renderBackground(matrices);
        optionList.render(matrices, mouseX, mouseY, tickDelta);
        drawCenteredText(matrices, this.textRenderer, this.title, this.width / 2, 20, 16777215);
        super.render(matrices, mouseX, mouseY, tickDelta);
        List<OrderedText> list = getHoveredButtonTooltip(optionList, mouseX, mouseY);
        if (list != null)
        {
            this.renderOrderedTooltip(matrices, list, mouseX, mouseY);
        }
    }
    *///?} elif =1.19.3 {
    /*public void render(MatrixStack matrices, int mouseX, int mouseY, float tickDelta)
    {
        this.renderBackground(matrices);
        optionList.render(matrices, mouseX, mouseY, tickDelta);
        drawCenteredText(matrices, this.textRenderer, this.title, this.width / 2, 20, 16777215);
        super.render(matrices, mouseX, mouseY, tickDelta);
    }
    *///?} elif =1.19.4 {
    /*@Override
    public void render(MatrixStack matrices, int mouseX, int mouseY, float delta)
    {
        this.renderBackgroundTexture(matrices);
        optionList.render(matrices, mouseX, mouseY, delta);
        drawCenteredTextWithShadow(matrices, this.textRenderer, this.title, this.width / 2, 5, 0xffffff);
        super.render(matrices, mouseX, mouseY, delta);
    }
    *///?} elif =1.20-1.20.1 {
    /*@Override
    public void render(DrawContext context, int mouseX, int mouseY, float delta)
    {
        optionList.render(context, mouseX, mouseY, delta);
        context.drawCenteredTextWithShadow(textRenderer, title, width / 2, 5, 0xffffff);
        super.render(context, mouseX, mouseY, delta);
    }
    *///?} else {
    @Override
    public void method_25394(class_332 context, int mouseX, int mouseY, float delta)
    {
        super.method_25394(context, mouseX, mouseY, delta);
        optionList.method_25394(context, mouseX, mouseY, delta);
        context.method_27534(field_22793, field_22785, field_22789 / 2, 5, 0xffffff);
    }
    //?}

    //? if =1.20.2 {
    /*@Override
    public void renderBackground(DrawContext context, int mouseX, int mouseY, float delta)
    {
        super.renderBackgroundTexture(context);
    }
    *///?}

    @Override
    protected void method_25426()
    {
        //? if <=1.19.3 {
        /*optionList = new ButtonListWidget(this.client, this.width, this.height, 32, this.height - 32, 25);
         *///?} elif =1.19.4 {
        /*optionList = new OptionListWidget(client, width, height, 32, height - 32, 25);
         *///?} elif =1.20-1.20.1 || =1.20.2 {
        /*optionList = new OptionListWidget(client, width, height, 32, height - 32, 32);
         *///?} elif =1.20.3-1.20.4 {
        /*optionList = new OptionListWidget(client, width, height - 66, 32, 32);
         *///?} elif =1.20.5-1.20.6 {
        /*optionList = new OptionListWidget(client, width, height, this);
         *///?} else {
        optionList = new class_353(field_22787, field_22789, this);
        //?}

        optionList.method_20408(CyanLibOptionsStorage.asConfigOptions(configOptionsClass));
        method_25429(optionList);

        //? if <=1.19.2 {
        /*addDrawableChild(new ButtonWidget(
                10, 6, 100, 20,
                //? if =1.18.2 {
                /^new TranslatableText("cyanlib.screen.config.reset"),
                ^///?} else {
                Text.translatable("cyanlib.screen.config.reset"),
                //?}
                button -> {
                    cyanLibOptionsStorage.resetOptions();
                    close();
                }
        ));
        addDrawableChild(new ButtonWidget(width / 2 - 100, height - 28, 200, 20, ScreenTexts.DONE, button -> close()));
        *///?} else {
        method_37063(
                class_4185.method_46430(
                                    class_2561.method_43471("cyanlib.screen.config.reset"), button -> {
                                        cyanLibOptionsStorage.resetOptions();
                                        method_25419();
                                    }
                            )
                            .method_46436(class_7919.method_47407(class_2561.method_43471("cyanlib.screen.config.reset.tooltip")))
                            .method_46434(10, 6, 100, 20)
                            .method_46431()
        );

        method_37063(
                class_4185.method_46430(class_5244.field_24334, button -> method_25419())
                            .method_46434(field_22789 / 2 - 100, field_22790 - 28, 200, 20)
                            .method_46431()
        );
        //?}
    }

    //? if >=1.21-1.21.1 {
    @Override
    protected void method_60325()
    {
    }
    //?}
}

==> cyanlib-1.0.10%2B1.20.2-sources.jar: fr/aeldit/cyanlib/lib/gui/CyanLibConfigScreen.java <==
package fr.aeldit.cyanlib.lib.gui;

import fr.aeldit.cyanlib.lib.config.CyanLibOptionsStorage;
import fr.aeldit.cyanlib.lib.config.ICyanLibConfig;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_353;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_4667;
import net.minecraft.class_5244;
import net.minecraft.class_7919;
import java.util.Objects;

import static fr.aeldit.cyanlib.lib.CyanLib.CONFIG_CLASS_INSTANCES;

@Environment(EnvType.CLIENT)
public class CyanLibConfigScreen extends class_4667
{
    private final CyanLibOptionsStorage cyanLibOptionsStorage;
    private final class_437 parent;
    private final ICyanLibConfig configOptionsClass;

    //? if <=1.19.3 {
    /*private ButtonListWidget optionList;
     *///?} else {
    private class_353 optionList;
    //?}

    public CyanLibConfigScreen(class_437 previous, class_437 parent, String modId)
    {
        super(
                previous, class_310.method_1551().field_1690,
                class_2561.method_43471("%s.screen.options.title".formatted(modId))
        );
        this.field_21335 = parent;
        this.cyanLibOptionsStorage = CONFIG_CLASS_INSTANCES.get(modId).getOptionsStorage();
        this.configOptionsClass = this.cyanLibOptionsStorage.getConfigClass();
    }

    @Override
    public void method_25419()
    {
        cyanLibOptionsStorage.writeConfig();
        Objects.requireNonNull(field_22787).method_1507(field_21335);
    }

    //? if <=1.19.2 {
    /*public void render(MatrixStack matrices, int mouseX, int mouseY, float tickDelta)
    {
        this.renderBackground(matrices);
        optionList.render(matrices, mouseX, mouseY, tickDelta);
        drawCenteredText(matrices, this.textRenderer, this.title, this.width / 2, 20, 16777215);
        super.render(matrices, mouseX, mouseY, tickDelta);
        List<OrderedText> list = getHoveredButtonTooltip(optionList, mouseX, mouseY);
        if (list != null)
        {
            this.renderOrderedTooltip(matrices, list, mouseX, mouseY);
        }
    }
    *///?} elif =1.19.3 {
    /*public void render(MatrixStack matrices, int mouseX, int mouseY, float tickDelta)
    {
        this.renderBackground(matrices);
        optionList.render(matrices, mouseX, mouseY, tickDelta);
        drawCenteredText(matrices, this.textRenderer, this.title, this.width / 2, 20, 16777215);
        super.render(matrices, mouseX, mouseY, tickDelta);
    }
    *///?} elif =1.19.4 {
    /*@Override
    public void render(MatrixStack matrices, int mouseX, int mouseY, float delta)
    {
        this.renderBackgroundTexture(matrices);
        optionList.render(matrices, mouseX, mouseY, delta);
        drawCenteredTextWithShadow(matrices, this.textRenderer, this.title, this.width / 2, 5, 0xffffff);
        super.render(matrices, mouseX, mouseY, delta);
    }
    *///?} elif =1.20-1.20.1 {
    /*@Override
    public void render(DrawContext context, int mouseX, int mouseY, float delta)
    {
        optionList.render(context, mouseX, mouseY, delta);
        context.drawCenteredTextWithShadow(textRenderer, title, width / 2, 5, 0xffffff);
        super.render(context, mouseX, mouseY, delta);
    }
    *///?} else {
    @Override
    public void method_25394(class_332 context, int mouseX, int mouseY, float delta)
    {
        super.method_25394(context, mouseX, mouseY, delta);
        optionList.method_25394(context, mouseX, mouseY, delta);
        context.method_27534(field_22793, field_22785, field_22789 / 2, 5, 0xffffff);
    }
    //?}

    //? if =1.20.2 {
    @Override
    public void method_25420(class_332 context, int mouseX, int mouseY, float delta)
    {
        super.method_25434(context);
    }
    //?}

    @Override
    protected void method_25426()
    {
        //? if <=1.19.3 {
        /*optionList = new ButtonListWidget(this.client, this.width, this.height, 32, this.height - 32, 25);
         *///?} elif =1.19.4 {
        /*optionList = new OptionListWidget(client, width, height, 32, height - 32, 25);
         *///?} elif =1.20-1.20.1 || =1.20.2 {
        optionList = new class_353(field_22787, field_22789, field_22790, 32, field_22790 - 32, 32);
         //?} elif =1.20.3-1.20.4 {
        /*optionList = new OptionListWidget(client, width, height - 66, 32, 32);
         *///?} elif =1.20.5-1.20.6 {
        /*optionList = new OptionListWidget(client, width, height, this);
         *///?} else {
        /*optionList = new OptionListWidget(client, width, this);
        *///?}

        optionList.method_20408(CyanLibOptionsStorage.asConfigOptions(configOptionsClass));
        method_25429(optionList);

        //? if <=1.19.2 {
        /*addDrawableChild(new ButtonWidget(
                10, 6, 100, 20,
                //? if =1.18.2 {
                /^new TranslatableText("cyanlib.screen.config.reset"),
                ^///?} else {
                Text.translatable("cyanlib.screen.config.reset"),
                //?}
                button -> {
                    cyanLibOptionsStorage.resetOptions();
                    close();
                }
        ));
        addDrawableChild(new ButtonWidget(width / 2 - 100, height - 28, 200, 20, ScreenTexts.DONE, button -> close()));
        *///?} else {
        method_37063(
                class_4185.method_46430(
                                    class_2561.method_43471("cyanlib.screen.config.reset"), button -> {
                                        cyanLibOptionsStorage.resetOptions();
                                        method_25419();
                                    }
                            )
                            .method_46436(class_7919.method_47407(class_2561.method_43471("cyanlib.screen.config.reset.tooltip")))
                            .method_46434(10, 6, 100, 20)
                            .method_46431()
        );

        method_37063(
                class_4185.method_46430(class_5244.field_24334, button -> method_25419())
                            .method_46434(field_22789 / 2 - 100, field_22790 - 28, 200, 20)
                            .method_46431()
        );
        //?}
    }

    //? if >=1.21-1.21.1 {
    /*@Override
    protected void addOptions()
    {
    }
    *///?}
}
